@@ -2,6 +2,19 @@ package RapidApp::Sugar;
 
 use strict;
 use warnings;
+
+die join("\n",
+  '','',
+  '  ***  WARNING  ***',
+  "  " . __PACKAGE__ . " is DEPRECATED. It has been replaced by consolidated 'RapidApp::Util' package",
+  "   [tip]: run `upgr-rapidapp.pl path/to/lib/` to upgrade your code automatically...",
+  '',''
+);
+
+1;
+__END__
+
+
 use Exporter qw( import );
 use Data::Dumper;
 use RapidApp::JSON::MixedEncoder;
@@ -15,10 +28,11 @@ use Hash::Merge qw( merge );
 Hash::Merge::set_behavior( 'RIGHT_PRECEDENT' );
 use Clone qw(clone);
 
+use Types::Standard qw(:all);
 
 our @EXPORT = qw(
   asjson rawjs mixedjs ashtml rawhtml usererr userexception 
-  jsfunc blessed merge hasarray hashash infostatus clone
+  jsfunc blessed merge infostatus clone
 );
 
 # Module shortcuts
@@ -187,51 +201,51 @@ sub userexception {
 
 # Suger function sets up a Native Trait ArrayRef attribute with useful
 # default accessor methods
-sub hasarray {
-	my $name = shift;
-	my %opt = @_;
-	
-	my %defaults = (
-		is => 'ro',
-		isa => 'ArrayRef',
-		traits => [ 'Array' ],
-		default => sub {[]},
-		handles => {
-			'all_' . $name => 'uniq',
-			'add_' . $name => 'push',
-			'insert_' . $name => 'unshift',
-			'has_no_' . $name => 'is_empty',
-			'count_' . $name		=> 'count'
-		}
-	);
-	
-	my $conf = merge(\%defaults,\%opt);
-	return caller->can('has')->($name,%$conf);
-}
+#sub hasarray {
+#	my $name = shift;
+#	my %opt = @_;
+#	
+#	my %defaults = (
+#		is => 'ro',
+#		isa => 'ArrayRef',
+#		traits => [ 'Array' ],
+#		default => sub {[]},
+#		handles => {
+#			'all_' . $name => 'uniq',
+#			'add_' . $name => 'push',
+#			'insert_' . $name => 'unshift',
+#			'has_no_' . $name => 'is_empty',
+#			'count_' . $name		=> 'count'
+#		}
+#	);
+#	
+#	my $conf = merge(\%defaults,\%opt);
+#	return caller->can('has')->($name,%$conf);
+#}
 
 # Suger function sets up a Native Trait HashRef attribute with useful
 # default accessor methods
-sub hashash {
-	my $name = shift;
-	my %opt = @_;
-	
-	my %defaults = (
-		is => 'ro',
-		isa => 'HashRef',
-		traits => [ 'Hash' ],
-		default => sub {{}},
-		handles => {
-			'apply_' . $name		=> 'set',
-			'get_' . $name			=> 'get',
-			'has_' . $name			=> 'exists',
-			'all_' . $name			=> 'values',
-			$name . '_names'		=> 'keys',
-		}
-	);
-	
-	my $conf = merge(\%defaults,\%opt);
-	return caller->can('has')->($name,%$conf);
-}
+#sub hashash {
+#	my $name = shift;
+#	my %opt = @_;
+#	
+#	my %defaults = (
+#		is => 'ro',
+#		isa => 'HashRef',
+#		traits => [ 'Hash' ],
+#		default => sub {{}},
+#		handles => {
+#			'apply_' . $name		=> 'set',
+#			'get_' . $name			=> 'get',
+#			'has_' . $name			=> 'exists',
+#			'all_' . $name			=> 'values',
+#			$name . '_names'		=> 'keys',
+#		}
+#	);
+#	
+#	my $conf = merge(\%defaults,\%opt);
+#	return caller->can('has')->($name,%$conf);
+#}
 
 
 sub infostatus {
